ValidationErrorKind

Enum ValidationErrorKind 

pub enum ValidationErrorKind {
Show 62 variants MultipleMainStatements { object_name: String, }, NoMainStatement { object_name: String, }, ObjectNameMismatch { declared: String, expected: String, }, SchemaMismatch { declared: String, expected: String, }, DatabaseMismatch { declared: String, expected: String, }, IndexReferenceMismatch { referenced: String, expected: String, }, GrantReferenceMismatch { referenced: String, expected: String, }, CommentReferenceMismatch { referenced: String, expected: String, }, ColumnCommentReferenceMismatch { referenced: String, expected: String, }, CommentTypeMismatch { comment_type: String, object_type: String, }, GrantTypeMismatch { grant_type: String, expected_type: String, }, UnsupportedStatement { object_name: String, statement_type: String, }, ClusterGrantUnsupported, GrantMustTargetObject, SystemGrantUnsupported, UnsupportedCommentType, NoObjectType, SchemaExtractionFailed, DatabaseExtractionFailed, InvalidIdentifier { name: String, reason: String, }, IndexMissingCluster { index_name: String, }, IndexOnStorageObject { object_type: String, object_name: String, index_name: String, }, MaterializedViewMissingCluster { view_name: String, }, SinkMissingCluster { sink_name: String, }, SourceMissingCluster { source_name: String, }, SourceExternalReferences { source_name: String, }, InvalidDatabaseModStatement { statement_type: String, database_name: String, }, DatabaseModCommentTargetMismatch { target: String, database_name: String, }, DatabaseModGrantTargetMismatch { target: String, database_name: String, }, InvalidSchemaModStatement { statement_type: String, schema_name: String, }, SchemaModCommentTargetMismatch { target: String, schema_name: String, }, SchemaModGrantTargetMismatch { target: String, schema_name: String, }, InvalidSetVariable { variable: String, value: String, }, AlterDefaultPrivilegesRequiresDatabaseScope { database_name: String, }, AlterDefaultPrivilegesRequiresSchemaScope { schema_name: String, }, AlterDefaultPrivilegesDatabaseMismatch { referenced: String, expected: String, }, AlterDefaultPrivilegesSchemaNotAllowed { database_name: String, }, AlterDefaultPrivilegesDatabaseNotAllowed { schema_name: String, }, AlterDefaultPrivilegesSchemaMismatch { referenced: String, expected: String, }, StorageAndComputationObjectsInSameSchema { schema_name: String, storage_objects: Vec<String>, computation_objects: Vec<String>, }, ReplacementSchemaNonMvObject { database: String, schema: String, object_name: String, object_type: ObjectKind, }, InvalidClusterStatement { statement_type: String, cluster_name: String, }, ClusterNameMismatch { declared: String, expected: String, }, ClusterMissingCreateStatement { cluster_name: String, }, ClusterMultipleCreateStatements { cluster_name: String, }, ClusterGrantTargetMismatch { target: String, cluster_name: String, }, ClusterCommentTargetMismatch { target: String, cluster_name: String, }, InvalidRoleStatement { statement_type: String, role_name: String, }, RoleNameMismatch { declared: String, expected: String, }, RoleMissingCreateStatement { role_name: String, }, RoleMultipleCreateStatements { role_name: String, }, RoleAlterTargetMismatch { target: String, role_name: String, }, RoleGrantTargetMismatch { target: String, role_name: String, }, RoleCommentTargetMismatch { target: String, role_name: String, }, InvalidNetworkPolicyStatement { statement_type: String, policy_name: String, }, NetworkPolicyNameMismatch { declared: String, expected: String, }, NetworkPolicyMissingCreateStatement { policy_name: String, }, NetworkPolicyMultipleCreateStatements { policy_name: String, }, NetworkPolicyGrantTargetMismatch { target: String, policy_name: String, }, NetworkPolicyCommentTargetMismatch { target: String, policy_name: String, }, ProfileObjectTypeMismatch { object_name: String, default_type: String, override_profile: String, override_type: String, default_path: PathBuf, override_path: PathBuf, }, ProfileOverrideNotAllowed { object_name: String, object_type: String, override_profile: String, override_path: PathBuf, },
}
The specific kind of validation error that occurred.

This enum contains the actual error variants without contextual information. Context (file path, SQL statement) is stored in the wrapping ValidationError.

Variants



MultipleMainStatements

A file contains multiple primary CREATE statements

Fields

object_name: String


NoMainStatement

A file contains no primary CREATE statement

Fields

object_name: String


ObjectNameMismatch

Object name in statement doesn’t match file name

Fields

declared: String
expected: String


SchemaMismatch

Schema qualifier in statement doesn’t match directory

Fields

declared: String
expected: String


DatabaseMismatch

Database qualifier in statement doesn’t match directory

Fields

declared: String
expected: String


IndexReferenceMismatch

An index references a different object

Fields

referenced: String
expected: String


GrantReferenceMismatch

A grant references a different object

Fields

referenced: String
expected: String


CommentReferenceMismatch

A comment references a different object

Fields

referenced: String
expected: String


ColumnCommentReferenceMismatch

A column comment references a different table

Fields

referenced: String
expected: String


CommentTypeMismatch

Comment object type doesn’t match actual object type

Fields

comment_type: String
object_type: String


GrantTypeMismatch

Grant object type doesn’t match actual object type

Fields

grant_type: String
expected_type: String


UnsupportedStatement

Unsupported statement type in object file

Fields

object_name: String
statement_type: String


ClusterGrantUnsupported

Unsupported grant type



GrantMustTargetObject

Grant doesn’t target specific object



SystemGrantUnsupported

System grant not supported



UnsupportedCommentType

Unsupported comment type



NoObjectType

No object type could be determined



SchemaExtractionFailed

Failed to extract schema name from file path



DatabaseExtractionFailed

Failed to extract database name from file path



InvalidIdentifier

Invalid identifier name (contains invalid characters or format)

Fields

name: String
reason: String


IndexMissingCluster

Index missing required IN CLUSTER clause

Fields

index_name: String


IndexOnStorageObject

Index defined on a storage object (table or source), which is unsupported.

Fields

object_type: String
object_name: String
index_name: String


MaterializedViewMissingCluster

Materialized view missing required IN CLUSTER clause

Fields

view_name: String


SinkMissingCluster

Sink missing required IN CLUSTER clause

Fields

sink_name: String


SourceMissingCluster

Source missing required IN CLUSTER clause

Fields

source_name: String


SourceExternalReferences

Source uses external references (FOR TABLES/FOR SCHEMAS/FOR ALL TABLES)

Fields

source_name: String


InvalidDatabaseModStatement

Invalid statement type in database mod file

Fields

statement_type: String
database_name: String


DatabaseModCommentTargetMismatch

Comment in database mod file targets wrong object

Fields

target: String
database_name: String


DatabaseModGrantTargetMismatch

Grant in database mod file targets wrong object

Fields

target: String
database_name: String


InvalidSchemaModStatement

Invalid statement type in schema mod file

Fields

statement_type: String
schema_name: String


SchemaModCommentTargetMismatch

Comment in schema mod file targets wrong object

Fields

target: String
schema_name: String


SchemaModGrantTargetMismatch

Grant in schema mod file targets wrong object

Fields

target: String
schema_name: String


InvalidSetVariable

SET variable in schema mod file has invalid value

Fields

variable: String
value: String


AlterDefaultPrivilegesRequiresDatabaseScope

ALTER DEFAULT PRIVILEGES in database mod requires IN DATABASE scope

Fields

database_name: String


AlterDefaultPrivilegesRequiresSchemaScope

ALTER DEFAULT PRIVILEGES in schema mod requires IN SCHEMA scope

Fields

schema_name: String


AlterDefaultPrivilegesDatabaseMismatch

ALTER DEFAULT PRIVILEGES IN DATABASE references wrong database

Fields

referenced: String
expected: String


AlterDefaultPrivilegesSchemaNotAllowed

ALTER DEFAULT PRIVILEGES cannot use IN SCHEMA in database mod

Fields

database_name: String


AlterDefaultPrivilegesDatabaseNotAllowed

ALTER DEFAULT PRIVILEGES cannot use IN DATABASE in schema mod

Fields

schema_name: String


AlterDefaultPrivilegesSchemaMismatch

ALTER DEFAULT PRIVILEGES IN SCHEMA references wrong schema

Fields

referenced: String
expected: String


StorageAndComputationObjectsInSameSchema

Storage objects (tables/sinks) and computation objects (views/MVs) cannot share a schema

Fields

schema_name: String
storage_objects: Vec<String>
computation_objects: Vec<String>


ReplacementSchemaNonMvObject

Replacement schema contains non-MV objects

Fields

database: String
schema: String
object_name: String
object_type: ObjectKind


InvalidClusterStatement

Invalid statement type in cluster definition file

Fields

statement_type: String
cluster_name: String


ClusterNameMismatch

Cluster name in CREATE CLUSTER doesn’t match filename

Fields

declared: String
expected: String


ClusterMissingCreateStatement

Cluster file missing required CREATE CLUSTER statement

Fields

cluster_name: String


ClusterMultipleCreateStatements

Cluster file contains multiple CREATE CLUSTER statements

Fields

cluster_name: String


ClusterGrantTargetMismatch

GRANT in cluster file targets a different cluster

Fields

target: String
cluster_name: String


ClusterCommentTargetMismatch

COMMENT in cluster file targets a different cluster

Fields

target: String
cluster_name: String


InvalidRoleStatement

Invalid statement type in role definition file

Fields

statement_type: String
role_name: String


RoleNameMismatch

Role name in CREATE ROLE doesn’t match filename

Fields

declared: String
expected: String


RoleMissingCreateStatement

Role file missing required CREATE ROLE statement

Fields

role_name: String


RoleMultipleCreateStatements

Role file contains multiple CREATE ROLE statements

Fields

role_name: String


RoleAlterTargetMismatch

ALTER ROLE in role file targets a different role

Fields

target: String
role_name: String


RoleGrantTargetMismatch

GRANT ROLE in role file targets a different role

Fields

target: String
role_name: String


RoleCommentTargetMismatch

COMMENT in role file targets a different role

Fields

target: String
role_name: String


InvalidNetworkPolicyStatement

Invalid statement type in network policy definition file

Fields

statement_type: String
policy_name: String


NetworkPolicyNameMismatch

Network policy name in CREATE NETWORK POLICY doesn’t match filename

Fields

declared: String
expected: String


NetworkPolicyMissingCreateStatement

Network policy file missing required CREATE NETWORK POLICY statement

Fields

policy_name: String


NetworkPolicyMultipleCreateStatements

Network policy file contains multiple CREATE NETWORK POLICY statements

Fields

policy_name: String


NetworkPolicyGrantTargetMismatch

GRANT in network policy file targets a different policy

Fields

target: String
policy_name: String


NetworkPolicyCommentTargetMismatch

COMMENT in network policy file targets a different policy

Fields

target: String
policy_name: String


ProfileObjectTypeMismatch

Profile variants of an object have different primary statement types

Fields

object_name: String
default_type: String
override_profile: String
override_type: String
default_path: PathBuf
override_path: PathBuf


ProfileOverrideNotAllowed

Views and materialized views cannot have profile-specific overrides

Fields

object_name: String
object_type: String
override_profile: String
override_path: PathBuf

Implementations

Source

impl ValidationErrorKind

pub(crate) fn message(&self) -> String

Get the short error message for this error kind

pub(crate) fn help(&self) -> Option<String>

Get the help text for this error kind