pub enum ValidationErrorKind {
Show 62 variants
MultipleMainStatements {
object_name: String,
},
NoMainStatement {
object_name: String,
},
ObjectNameMismatch {
declared: String,
expected: String,
},
SchemaMismatch {
declared: String,
expected: String,
},
DatabaseMismatch {
declared: String,
expected: String,
},
IndexReferenceMismatch {
referenced: String,
expected: String,
},
GrantReferenceMismatch {
referenced: String,
expected: String,
},
CommentReferenceMismatch {
referenced: String,
expected: String,
},
ColumnCommentReferenceMismatch {
referenced: String,
expected: String,
},
CommentTypeMismatch {
comment_type: String,
object_type: String,
},
GrantTypeMismatch {
grant_type: String,
expected_type: String,
},
UnsupportedStatement {
object_name: String,
statement_type: String,
},
ClusterGrantUnsupported,
GrantMustTargetObject,
SystemGrantUnsupported,
UnsupportedCommentType,
NoObjectType,
SchemaExtractionFailed,
DatabaseExtractionFailed,
InvalidIdentifier {
name: String,
reason: String,
},
IndexMissingCluster {
index_name: String,
},
IndexOnStorageObject {
object_type: String,
object_name: String,
index_name: String,
},
MaterializedViewMissingCluster {
view_name: String,
},
SinkMissingCluster {
sink_name: String,
},
SourceMissingCluster {
source_name: String,
},
SourceExternalReferences {
source_name: String,
},
InvalidDatabaseModStatement {
statement_type: String,
database_name: String,
},
DatabaseModCommentTargetMismatch {
target: String,
database_name: String,
},
DatabaseModGrantTargetMismatch {
target: String,
database_name: String,
},
InvalidSchemaModStatement {
statement_type: String,
schema_name: String,
},
SchemaModCommentTargetMismatch {
target: String,
schema_name: String,
},
SchemaModGrantTargetMismatch {
target: String,
schema_name: String,
},
InvalidSetVariable {
variable: String,
value: String,
},
AlterDefaultPrivilegesRequiresDatabaseScope {
database_name: String,
},
AlterDefaultPrivilegesRequiresSchemaScope {
schema_name: String,
},
AlterDefaultPrivilegesDatabaseMismatch {
referenced: String,
expected: String,
},
AlterDefaultPrivilegesSchemaNotAllowed {
database_name: String,
},
AlterDefaultPrivilegesDatabaseNotAllowed {
schema_name: String,
},
AlterDefaultPrivilegesSchemaMismatch {
referenced: String,
expected: String,
},
StorageAndComputationObjectsInSameSchema {
schema_name: String,
storage_objects: Vec<String>,
computation_objects: Vec<String>,
},
ReplacementSchemaNonMvObject {
database: String,
schema: String,
object_name: String,
object_type: ObjectKind,
},
InvalidClusterStatement {
statement_type: String,
cluster_name: String,
},
ClusterNameMismatch {
declared: String,
expected: String,
},
ClusterMissingCreateStatement {
cluster_name: String,
},
ClusterMultipleCreateStatements {
cluster_name: String,
},
ClusterGrantTargetMismatch {
target: String,
cluster_name: String,
},
ClusterCommentTargetMismatch {
target: String,
cluster_name: String,
},
InvalidRoleStatement {
statement_type: String,
role_name: String,
},
RoleNameMismatch {
declared: String,
expected: String,
},
RoleMissingCreateStatement {
role_name: String,
},
RoleMultipleCreateStatements {
role_name: String,
},
RoleAlterTargetMismatch {
target: String,
role_name: String,
},
RoleGrantTargetMismatch {
target: String,
role_name: String,
},
RoleCommentTargetMismatch {
target: String,
role_name: String,
},
InvalidNetworkPolicyStatement {
statement_type: String,
policy_name: String,
},
NetworkPolicyNameMismatch {
declared: String,
expected: String,
},
NetworkPolicyMissingCreateStatement {
policy_name: String,
},
NetworkPolicyMultipleCreateStatements {
policy_name: String,
},
NetworkPolicyGrantTargetMismatch {
target: String,
policy_name: String,
},
NetworkPolicyCommentTargetMismatch {
target: String,
policy_name: String,
},
ProfileObjectTypeMismatch {
object_name: String,
default_type: String,
override_profile: String,
override_type: String,
default_path: PathBuf,
override_path: PathBuf,
},
ProfileOverrideNotAllowed {
object_name: String,
object_type: String,
override_profile: String,
override_path: PathBuf,
},
}Expand description
The specific kind of validation error that occurred.
This enum contains the actual error variants without contextual information.
Context (file path, SQL statement) is stored in the wrapping ValidationError.
Variants
MultipleMainStatements
A file contains multiple primary CREATE statements
NoMainStatement
A file contains no primary CREATE statement
ObjectNameMismatch
Object name in statement doesn’t match file name
SchemaMismatch
Schema qualifier in statement doesn’t match directory
DatabaseMismatch
Database qualifier in statement doesn’t match directory
IndexReferenceMismatch
An index references a different object
GrantReferenceMismatch
A grant references a different object
CommentReferenceMismatch
A comment references a different object
ColumnCommentReferenceMismatch
A column comment references a different table
CommentTypeMismatch
Comment object type doesn’t match actual object type
GrantTypeMismatch
Grant object type doesn’t match actual object type
UnsupportedStatement
Unsupported statement type in object file
ClusterGrantUnsupported
Unsupported grant type
GrantMustTargetObject
Grant doesn’t target specific object
SystemGrantUnsupported
System grant not supported
UnsupportedCommentType
Unsupported comment type
NoObjectType
No object type could be determined
SchemaExtractionFailed
Failed to extract schema name from file path
DatabaseExtractionFailed
Failed to extract database name from file path
InvalidIdentifier
Invalid identifier name (contains invalid characters or format)
IndexMissingCluster
Index missing required IN CLUSTER clause
IndexOnStorageObject
Index defined on a storage object (table or source), which is unsupported.
MaterializedViewMissingCluster
Materialized view missing required IN CLUSTER clause
SinkMissingCluster
Sink missing required IN CLUSTER clause
SourceMissingCluster
Source missing required IN CLUSTER clause
SourceExternalReferences
Source uses external references (FOR TABLES/FOR SCHEMAS/FOR ALL TABLES)
InvalidDatabaseModStatement
Invalid statement type in database mod file
DatabaseModCommentTargetMismatch
Comment in database mod file targets wrong object
DatabaseModGrantTargetMismatch
Grant in database mod file targets wrong object
InvalidSchemaModStatement
Invalid statement type in schema mod file
SchemaModCommentTargetMismatch
Comment in schema mod file targets wrong object
SchemaModGrantTargetMismatch
Grant in schema mod file targets wrong object
InvalidSetVariable
SET variable in schema mod file has invalid value
AlterDefaultPrivilegesRequiresDatabaseScope
ALTER DEFAULT PRIVILEGES in database mod requires IN DATABASE scope
AlterDefaultPrivilegesRequiresSchemaScope
ALTER DEFAULT PRIVILEGES in schema mod requires IN SCHEMA scope
AlterDefaultPrivilegesDatabaseMismatch
ALTER DEFAULT PRIVILEGES IN DATABASE references wrong database
AlterDefaultPrivilegesSchemaNotAllowed
ALTER DEFAULT PRIVILEGES cannot use IN SCHEMA in database mod
AlterDefaultPrivilegesDatabaseNotAllowed
ALTER DEFAULT PRIVILEGES cannot use IN DATABASE in schema mod
AlterDefaultPrivilegesSchemaMismatch
ALTER DEFAULT PRIVILEGES IN SCHEMA references wrong schema
StorageAndComputationObjectsInSameSchema
Storage objects (tables/sinks) and computation objects (views/MVs) cannot share a schema
ReplacementSchemaNonMvObject
Replacement schema contains non-MV objects
InvalidClusterStatement
Invalid statement type in cluster definition file
ClusterNameMismatch
Cluster name in CREATE CLUSTER doesn’t match filename
ClusterMissingCreateStatement
Cluster file missing required CREATE CLUSTER statement
ClusterMultipleCreateStatements
Cluster file contains multiple CREATE CLUSTER statements
ClusterGrantTargetMismatch
GRANT in cluster file targets a different cluster
ClusterCommentTargetMismatch
COMMENT in cluster file targets a different cluster
InvalidRoleStatement
Invalid statement type in role definition file
RoleNameMismatch
Role name in CREATE ROLE doesn’t match filename
RoleMissingCreateStatement
Role file missing required CREATE ROLE statement
RoleMultipleCreateStatements
Role file contains multiple CREATE ROLE statements
RoleAlterTargetMismatch
ALTER ROLE in role file targets a different role
RoleGrantTargetMismatch
GRANT ROLE in role file targets a different role
RoleCommentTargetMismatch
COMMENT in role file targets a different role
InvalidNetworkPolicyStatement
Invalid statement type in network policy definition file
NetworkPolicyNameMismatch
Network policy name in CREATE NETWORK POLICY doesn’t match filename
NetworkPolicyMissingCreateStatement
Network policy file missing required CREATE NETWORK POLICY statement
NetworkPolicyMultipleCreateStatements
Network policy file contains multiple CREATE NETWORK POLICY statements
NetworkPolicyGrantTargetMismatch
GRANT in network policy file targets a different policy
NetworkPolicyCommentTargetMismatch
COMMENT in network policy file targets a different policy
ProfileObjectTypeMismatch
Profile variants of an object have different primary statement types
Fields
ProfileOverrideNotAllowed
Views and materialized views cannot have profile-specific overrides
Implementations